YARP 2.3.66.2 (2016-11-28)                                          {#v2_3_66_2}
==========================

[TOC]

YARP 2.3.66.2 Release Notes
===========================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+YARP+v2.3.66.2%22).


Important Changes
-----------------

Bug Fixes
---------

### YARP_OS

* Fixed `join()` return values of threads when C++11 compilation is activated.
* Fixed segmentation fault while closing YARP modules. (#942)

### YARP_dev

* Added missing `YARP_dev_API` to ControlBoard interfaces.
* Fixed segfault in `controlboardwrapper2` for multiJoints functions

### GUIs

* `yarpdataplayer`
  * Dataset with one entry can now be played. (#936)
  * Resetting `sendstrict` upon new dataset. (#941)
* `yarplogger`
  * Open logs by drag'n'drop. (#934)

### Devices

* `serial`
  * Print error when the device cannot be opened.

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.66.1..v2.3.66.2`):

```
    13	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
     4	Vadim Tikhanoff <vadim.tikhanoff@iit.it>
     3	Claudio Fantacci <claudio.fantacci@iit.it>
     3	Matteo Brunettini <matteo.brunettini@iit.it>
     2	Alberto Cardellino <alberto.cardellino@iit.it>
     1	Alexandros Paraschos <paraschos@ias.tu-darmstadt.de>
     1	Gabriele Nava <gabriele.nava@mail.polimi.it>
     1	Giovanni Saponaro <gsaponaro@isr.ist.utl.pt>
     1	Marco Randazzo <marco.randazzo@iit.it>
     1	Silvio Traversaro <silvio.traversaro@iit.it>
```
